==> academy-document-core-1.0.0-sources.jar: com/ptteng/sca/academy/document/client/UserFavoriteRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.academy.document.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.academy.document.model.UserFavoriteRelation;
import com.ptteng.academy.document.service.UserFavoriteRelationService;

import java.util.List;
import java.util.Map;

public class UserFavoriteRelationSCAClient implements UserFavoriteRelationService {

    private UserFavoriteRelationService userFavoriteRelationService;

	public UserFavoriteRelationService getUserFavoriteRelationService() {
		return userFavoriteRelationService;
	}
	
	
	public void setUserFavoriteRelationService(UserFavoriteRelationService userFavoriteRelationService) {
		this.userFavoriteRelationService =userFavoriteRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserFavoriteRelation userFavoriteRelation)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.insert(userFavoriteRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserFavoriteRelation> insertList(List<UserFavoriteRelation> userFavoriteRelationList)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.insertList(userFavoriteRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserFavoriteRelation userFavoriteRelation)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.update(userFavoriteRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserFavoriteRelation> userFavoriteRelationList)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.updateList(userFavoriteRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserFavoriteRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserFavoriteRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndType(Long targetId,Long uid,Integer targetType,Integer type)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndType(targetId,uid,targetType,type);
	
	
	}

	@Override
	public Long getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndTypeAndStatus(Long targetId, Long uid, Integer targetType, Integer type, Integer status) throws ServiceException, ServiceDaoException {
		return userFavoriteRelationService.getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndTypeAndStatus(targetId,uid,targetType,type,status);
	}

	@Override
	public List<Long> getUserFavoriteRelationIdByUidAndTargetTypeAndTypeAndStatus(Long uid, Integer targetType, Integer type, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userFavoriteRelationService.getUserFavoriteRelationIdByUidAndTargetTypeAndTypeAndStatus(uid, targetType, type, status, start, limit);
	}


	@Override
	public List<Long> getUserFavoriteRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.getUserFavoriteRelationIds(start, limit);
	}

	@Override
	public Integer countUserFavoriteRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.countUserFavoriteRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userFavoriteRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userFavoriteRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> academy-document-core-2.0.0-sources.jar: com/ptteng/sca/academy/document/client/UserFavoriteRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.academy.document.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.academy.document.model.UserFavoriteRelation;
import com.ptteng.academy.document.service.UserFavoriteRelationService;

import java.util.List;
import java.util.Map;

public class UserFavoriteRelationSCAClient implements UserFavoriteRelationService {

    private UserFavoriteRelationService userFavoriteRelationService;

	public UserFavoriteRelationService getUserFavoriteRelationService() {
		return userFavoriteRelationService;
	}
	
	
	public void setUserFavoriteRelationService(UserFavoriteRelationService userFavoriteRelationService) {
		this.userFavoriteRelationService =userFavoriteRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserFavoriteRelation userFavoriteRelation)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.insert(userFavoriteRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserFavoriteRelation> insertList(List<UserFavoriteRelation> userFavoriteRelationList)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.insertList(userFavoriteRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserFavoriteRelation userFavoriteRelation)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.update(userFavoriteRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserFavoriteRelation> userFavoriteRelationList)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.updateList(userFavoriteRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserFavoriteRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserFavoriteRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndType(Long targetId,Long uid,Integer targetType,Integer type)throws ServiceException, ServiceDaoException{
		
		return userFavoriteRelationService.getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndType(targetId,uid,targetType,type);
	
	
	}

	@Override
	public Long getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndTypeAndStatus(Long targetId, Long uid, Integer targetType, Integer type, Integer status) throws ServiceException, ServiceDaoException {
		return userFavoriteRelationService.getUserFavoriteRelationIdByTargetIdAndUidAndTargetTypeAndTypeAndStatus(targetId,uid,targetType,type,status);
	}

	@Override
	public List<Long> getUserFavoriteRelationIdByUidAndTargetTypeAndTypeAndStatus(Long uid, Integer targetType, Integer type, Integer status, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userFavoriteRelationService.getUserFavoriteRelationIdByUidAndTargetTypeAndTypeAndStatus(uid, targetType, type, status, start, limit);
	}


	@Override
	public List<Long> getUserFavoriteRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.getUserFavoriteRelationIds(start, limit);
	}

	@Override
	public Integer countUserFavoriteRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.countUserFavoriteRelationIds();
	}

	@Override
	public List<Long> getUserFavoriteRelationIdsByUserIDAndType(Long userID, Integer type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userFavoriteRelationService.getUserFavoriteRelationIdsByUserIDAndType(userID, type, start, limit);
	}


	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userFavoriteRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userFavoriteRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userFavoriteRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}
